######################
Changes in glymur 0.10
######################

*****************
Changes in 0.10.2
*****************

    * Fix appveyor builds.
    * Fix tiff2jp2 when ExifTag is present.
    * Address warnings in TIFF interface.
    * Update glymur.config documentation.

*****************
Changes in 0.10.1
*****************

    * Add write capability for Resolution boxes.
    * Add example documentation for reading layers.

*****************
Changes in 0.10.0
*****************

    * Allow parsing of Exif UUIDs missing the EXIF\00\00 lead-in.
    * Add read support for additional Exif tags.
    * Add support for TLM segment generation.

